package com.taauav.admin.controller;


import com.taauav.common.bean.Response;
import com.taauav.common.constant.PermissionConstants;
import com.taauav.admin.entity.TauvInspectFile;
import com.taauav.admin.entity.TauvQuestionOptions;
import com.taauav.admin.service.ITauvInspectFileService;
import com.taauav.admin.service.ITauvQuestionOptionsService;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import java.io.*;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 巡检附件表 前端控制器
 * </p>
 *
 * @author dyg
 * @since 2019-11-14
 */
@RestController
@RequestMapping("inspectfile")
@Slf4j
public class TauvInspectFileController {
    @Autowired
    private ITauvInspectFileService inspectFileService;

    @Value("${file.uploadFolder}")
    private String uploadFolder;
    @Value("${server.UPLOAD_URL}")
    private String uploadUrl;
    @Autowired
    private Response response;
    @Autowired
    private ITauvQuestionOptionsService questionService;
    private static final String controllerName = "inspectfile";

    /**
     * 图片列表
     * @param map
     * @return
     */
    @PostMapping("picList")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.LIST_PERMISSION)
    public Response picList(@RequestBody Map<String,Object> map) {
        if (map == null) {
            map = new HashMap<>();
        }
        if (StringUtils.isEmpty(map.get("status"))) {
            map.put("status", "3,4,5,6");
        }
        return inspectFileService.getPageList(map, "pic");
    }

    /**
     * 图片上传
     * @param map
     * @return
     */
    @PostMapping("uploadPic")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.UPLOAD_PERMISSION)
    public Response uploadPic(@RequestBody Map<String, Object> map) throws IOException {
        return inspectFileService.uploadPic(map);
    }


    /**
     * 视频列表
     * @param map
     * @return
     */
    @PostMapping("videoList")
    @RequiresPermissions(controllerName + ":videoList")
    public Response videoList(@RequestBody(required = false) Map<String,Object> map) {
        return inspectFileService.getPageList(map, "video");
    }

    /**
     * 图片分类
     * @return
     */
    @GetMapping("document")
    public Response document() {
        return inspectFileService.getDocumentList();
    }

    /**
     * 查看任务的图集
     * @param id
     * @return
     */
    @GetMapping("view")
    @RequiresPermissions(controllerName +":"+ PermissionConstants.VIEW_PERMISSION)
    public Response view(@RequestParam("id") Integer id) {
        return inspectFileService.view(id);
    }

    /**
     * 标记
     */
    @GetMapping("setMark")
    @RequiresPermissions(controllerName + ":setMark")
    public Response setMark(@RequestParam("id") Integer id) {
        return inspectFileService.view(id);
    }

    /**
     * 获取问题选项
     * @return
     */
    @GetMapping("questionList")
    public Response questionList() {
        List<TauvQuestionOptions> list = questionService.getDataList();
        return response.success("操作成功", list);
    }

    /**
     * 标记已完成
     * @param id
     * @return
     */
    @GetMapping("setMarkFinish")
    @RequiresPermissions(controllerName + ":markFinish")
    public Response setMarkFinish( @RequestParam("id") Integer id) {
        return inspectFileService.setMarkFinish(id);
    }

    /**
     * 图片列表删除所有图片
     * @param map inspect_driver表中的id
     * @return
     */
    @PostMapping("drop")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.REMOVE_PERMISSION)
    public Response drop(@RequestBody Map<String, Integer> map) {
        if (map == null || !map.containsKey("id") || "".equals(map.get("id")) || map.get("id") <= 0) {
            return response.failure("参数错误");
        }
        Integer id = map.get("id");
        return inspectFileService.drop(id);
    }

    /**
     * 取消标记
     * @param id inspect_file表中的id
     * @return
     */
    @GetMapping("cancelMark")
    @RequiresPermissions(controllerName + ":cancel")
    public Response cancelMark(@RequestParam("id") Integer id) {
        return inspectFileService.cancelMark(id);
    }

    /**
     * 保存标记的图片
     * @param map
     * @return
     */
    @PostMapping("savePic")
    @RequiresPermissions(controllerName + ":savePic")
    public Response savePic(@RequestBody Map<String,String> map) {
        return inspectFileService.savePic(map);
    }

    /**
     * 删除图片
     * @param id inspect_file表中的id
     * @return
     */
    @GetMapping("dropPic")
    @RequiresPermissions(controllerName + ":dropPic")
    public Response dropPic(@RequestParam("id") Integer id) {
        return inspectFileService.dropPic(id);
    }

    /**
     * 下载文件
     * @param ids
     * @return
     */
    @GetMapping("download")
    @RequiresPermissions(controllerName + ":" + PermissionConstants.DOWNLOAD_PERMISSION)
    public Response  download(@RequestBody @RequestParam("ids") String ids) {
        File downloadFile = inspectFileService.getDownloadFileByIds(ids);
        String filePath = downloadFile.getPath();
        filePath = filePath.replaceAll("\\\\","/");
        filePath = filePath.replace(uploadFolder, uploadUrl);
        return response.success("操作成功", filePath);
    }

    /**
     * 下载图片
     * @param id
     * @return
     */
    @GetMapping("downPic")
    public String  downPic(@RequestParam("id") Integer id) {
        if (StringUtils.isEmpty(id)) {
            return "参数不全";
        }

        TauvInspectFile inspectFile = inspectFileService.getInfoById(id);
        if (StringUtils.isEmpty(inspectFile)) {
            return "";
        }

        String  originImg = inspectFile.getOriginalImg();
        File originFile = new File(uploadFolder+originImg);
        return inspectFileService.downFile(originFile);
    }

    /**
     * 图片复核列表
     * @param map
     * @return
     */
    @PostMapping("review")
    @RequiresPermissions(controllerName + ":review")
    public Response review(@RequestBody(required = false) Map<String,Object> map) {
        if (map != null && map.containsKey("type") && !"".equals(map.get("type"))) {
            Integer type = Integer.valueOf(map.get("type").toString());
            if (type == 1) {
                map.put("status", 5);
            } else if (type == 2) {
                map.put("status", "4,6");
            }
        } else {
            map.put("status", "5,6");
        }
        return inspectFileService.getPageList(map, "pic");
    }

    /**
     * 获取复核图片数据
     * @param id
     * @return
     */
    @GetMapping("getReviewPic")
    public Response getReviewPic(@RequestParam("id") Integer id) {
        return inspectFileService.getReviewPic(id);
    }

    /**
     * 复核图片保存数据
     * @param list
     * @return
     */
    @PostMapping("reviewPic")
    @RequiresPermissions(controllerName + ":reviewPic")
    public Response reviewPic(@RequestBody List<Map<String,String>> list) {
        return inspectFileService.reviewPic(list);
    }

    /**
     * 复核完成
     * @param id
     * @return
     */
    @GetMapping("reviewFinish")
    @RequiresPermissions(controllerName + ":reviewFinish")
    public Response reviewFinish(@RequestParam("id") Integer id) {
        return inspectFileService.reviewFinish(id);
    }
}
