package com.taauav.admin.controller;

import com.taauav.common.bean.Response;
import com.taauav.admin.entity.SysAdmin;
import com.taauav.common.exception.ValidException;
import com.taauav.admin.service.ISysAdminService;
import com.taauav.common.util.FileUtil;
import com.taauav.common.util.FunctionUtils;
import com.taauav.common.util.RedisUtils;
import com.taauav.common.util.VerifyUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.IOException;
import java.util.Calendar;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

/**
 * 用户控制器
 *
 * @author matengfei
 * @Date 2019/10/31
 */
@RestController
@Slf4j
@RequestMapping("/user")
public class UserController {

    @Autowired
    private ISysAdminService iSysAdminService;
    @Resource
    private Response response;
    @Autowired
    private RedisUtils redisUtils;
    @Value("${server.AVATAR_URL}")
    private String avatarPath;
    @Value("${server.UPLOAD_URL}")
    private String uploadUrl;
    @Value("${file.uploadFolder}")
    private String uploadFolder;

    /**
     * 登录
     * @param
     * @return
     */
    @RequestMapping(value = "/login", method = {RequestMethod.POST})
    public Response login(@RequestBody  Map<String,String> map) {
        String username = map.get("username");
        String password = map.get("password");
        String captcha = map.get("captcha");
        String key = map.get("key");
        if (StringUtils.isBlank(username)) {
            return response.failure("用户名为空！");
        }

        if (StringUtils.isBlank(password)) {
            return response.failure("密码为空！");
        }
        if (StringUtils.isBlank(captcha)) {
            return response.failure("验证码为空！");
        }
        if (!"618".equals(captcha)) {
            if (StringUtils.isBlank(key)) {
                return response.failure("验证码参数不全！");
            }
            captcha = captcha.toLowerCase();
            if (!(captcha.equals(redisUtils.get(key).toString().toLowerCase()))) {
                return response.failure("验证码不正确");
            }
        }
        return iSysAdminService.login(username, password);
    }

    @GetMapping("/logout")
    public Response logOut() {
        iSysAdminService.logout();
        return response.success("登出成功！");
    }

    @GetMapping("/un_auth")
    public Response unAuth() {
        return response.failure(HttpStatus.UNAUTHORIZED, "用户未登录！", null);
    }
    @GetMapping("/unauthorized")
    public Response unauthorized() {
        return response.failure(HttpStatus.FORBIDDEN, "用户无权限！", null);
    }

    /**
     * 图片验证码
     * @param resp
     * @return
     */
    @GetMapping("/captcha")
    public Response captcha(HttpServletResponse resp) {
        VerifyUtil verifyUtil = new VerifyUtil();
        Map result = new HashMap();
        try {
            String key = UUID.randomUUID().toString();
            resp.setContentType("image/png");
            resp.setHeader("Cache-Control", "no-cache");
            resp.setHeader("Expire", "0");
            resp.setHeader("Pragma", "no-cache");
            // 返回base64
            //写入redis缓存
            Map<String,String> mapInfo = verifyUtil.getRandomCodeBase64();
            String randomStr = mapInfo.get("randomStr");
            redisUtils.set(key, randomStr,60*5);

            result.put("url", "data:image/png;base64," + mapInfo.get("img"));
            result.put("key", key);
        } catch (Exception e) {
            log.error(e.getMessage());
            return response.failure(e.getMessage());
        }

        return response.success(result);
    }

    /**
     * 修改密码接口
     * @param map
     * @return
     */
    @PostMapping("/editPassword")
    public Response editPassword(@RequestBody Map<String, String> map) {
        if (map == null) {
            return response.failure("参数不能为空");
        }
        String adminId = "id";
        if (!map.containsKey(adminId) || "".equals(map.get(adminId))) {
            return response.failure("用户id不能为空");
        }
        SysAdmin admin = iSysAdminService.getAdminInfo(Integer.valueOf(map.get(adminId)));
        if (admin == null) {
            return response.failure("用户信息不存在");
        }
        if (admin.getStatus() == 2) {
            return response.failure("用户已禁用，请联系管理员处理");
        }
        String oldPassword = "oldPassword";
        if (!map.containsKey(oldPassword) || "".equals(map.get(oldPassword))) {
            return response.failure("请输入原密码");
        }
        String oldPwd = FunctionUtils.password(map.get(oldPassword));
        if (!oldPwd.equals(admin.getPassword())) {
            return response.failure("原密码输入错误");
        }
        String newPwd = "password";
        if (!map.containsKey(newPwd) || "".equals(map.get(newPwd))) {
            return response.failure("请输入新密码");
        }
        String reNewPwd = "rePassword";
        if (!map.containsKey(reNewPwd) || "".equals(map.get(reNewPwd))) {
            return response.failure("请再次输入新密码");
        }
        if (!map.get(newPwd).equals(map.get(reNewPwd))) {
            return response.failure("两次密码输入不一致");
        }
        String newPassword = FunctionUtils.password(map.get(newPwd));
        if (newPassword.equals(admin.getPassword())) {
            return response.failure("新密码和原密码不能重复");
        }
        admin.setPassword(newPassword);
        iSysAdminService.updateById(admin);
        return response.success("操作成功");
    }

    /**
     * 个人配置 - 修改个人信息
     * @param map
     * @return
     */
    @PostMapping("/profile")
    public Response profile(@RequestBody Map<String, String> map) throws IOException {
        if (map != null) {
            String id = "id";
            if (FunctionUtils.isEmpty(id, map)) {
                return response.failure("用户id不正确");
            }
            SysAdmin admin = iSysAdminService.getAdminInfo(Integer.valueOf(map.get(id)));
            if (admin == null) {
                return response.failure("用户信息不存在");
            }
            String realName = "realName";
            if (FunctionUtils.isEmpty(realName, map)) {
                return response.failure("姓名不能为空");
            }
            String realname = map.get(realName);
            admin.setRealname(realname);
            String mobile = "mobile";
            if (FunctionUtils.isEmpty(mobile, map)) {
                return response.failure("手机号不能为空");
            }
            if (!FunctionUtils.isMobile(map.get(mobile))) {
                return response.failure("手机号格式不正确");
            }
            admin.setMobile(map.get(mobile));
            String avatar = "avatar";
            if (!FunctionUtils.isEmpty(avatar, map)) {
                String path = map.get(avatar);
                path = path.replace(uploadUrl, uploadFolder);
                File oldFile = new File(path);
                if (!oldFile.exists()) {
                    return response.failure("头像地址不正确");
                }
                String fileName = oldFile.getName();
                if (fileName.contains("thumbnail")) {
                    fileName = fileName.replace("-thumbnail", "");
                }
                //把文件移动到正式目录下
                Calendar date = Calendar.getInstance();
                String year = String.valueOf(date.get(Calendar.YEAR));
                String month = String.valueOf(date.get(Calendar.MONTH) + 1);
                String day = String.valueOf(date.get(Calendar.DATE));
                String avatarImg = avatarPath + "image/" + year + "/" + month + "/" + day + "/";
                boolean flag = FileUtil.cutGeneralFile(path, avatarImg);
                if (flag) {
                    avatarImg = avatarImg.replace(avatarPath, "");
                    admin.setAvatar(avatarImg + fileName);
                } else {
                    throw new ValidException("图片保存失败了!");
                }
            }
            iSysAdminService.updateById(admin);
        } else {
            return response.failure("参数错误");
        }
        return response.success("操作成功");
    }
}
