package com.taauav.admin.service;

import com.taauav.common.bean.Response;
import com.taauav.admin.entity.SysAdmin;
import com.taauav.admin.entity.SysAuthGroup;
import com.taauav.common.service.IBaseService;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 用户组表 服务类
 * </p>
 *
 * @author dyg
 * @since 2019-11-04
 */
public interface ISysAuthGroupService extends IBaseService<SysAuthGroup> {

    /**
     * 根据用户编号获取权限
     *
     * @param adminId
     * @return
     */
    List<SysAuthGroup> getAuthGroups(Integer adminId);

    /**
     * 根据父级编号获取数据
     *
     * @param pid
     * @return
     */
    List<Map<String, String>> getListByPid(Integer pid);

    /**
     * 获取权限列表
     *
     * @param map
     * @return
     */
    Response getList(Map<String, String> map);

    /**
     * 添加权限
     *
     * @param authGroup
     * @return
     */
    Response add(SysAuthGroup authGroup);

    /**
     * 编辑
     *
     * @param authGroup
     * @return
     */
    Response edit(SysAuthGroup authGroup);

    /**
     * 删除
     *
     * @param authGroup
     * @return
     */
    Response del(SysAuthGroup authGroup);

    /**
     * 配置
     *
     * @param map
     * @return
     */
    Response setRules(Map<String, String> map);

    /**
     * 修改角色状态
     *
     * @param map
     * @return
     */
    Response editStatus(Map<String, String> map);

    /**
     * 根据ID获取数据
     *
     * @param id
     * @return
     */
    SysAuthGroup getInfoById(Integer id);

    /**
     * 根据名称获取数据
     *
     * @param name
     * @return
     */
    SysAuthGroup getInfoByName(String name);

    /**
     * 获取当前用户角色 1 内部用户 2外部用户
     *
     * @return
     */
    Integer getAuthGroupPid();

    /**
     * 判断用户是否为飞行小组成员
     *
     * @param admin
     * @return
     */
    Boolean isFlightHand(SysAdmin admin);
}
