package com.taauav.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.taauav.common.bean.Response;
import com.taauav.admin.entity.SysDictType;
import com.taauav.admin.mapper.SysDictTypeMapper;
import com.taauav.admin.service.ISysAdminService;
import com.taauav.admin.service.ISysDictTypeService;
import com.taauav.common.service.impl.BaseServiceImpl;
import com.taauav.common.util.DateUtil;
import com.taauav.common.util.FunctionUtils;
import com.taauav.common.util.ShiroUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import javax.validation.ConstraintViolation;
import javax.validation.Validator;
import java.time.LocalDateTime;
import java.util.Map;
import java.util.Set;

/**
 * <p>
 * 系统字典分类表 服务实现类
 * </p>
 *
 * @author dyg
 * @since 2019-11-14
 */
@Service
public class SysDictTypeServiceImpl extends BaseServiceImpl<SysDictTypeMapper, SysDictType> implements ISysDictTypeService {
    @Value("${spring.pageSize}")
    private Integer pageSize;
    @Autowired
    private Response response;
    @Resource
    private Validator validator;
    @Autowired
    private SysDictTypeMapper dictTypeMapper;
    @Autowired
    private ISysAdminService adminService;

    /**
     * 获取分页列表数据
     *
     * @param map
     * @return
     */
    @Override
    public Response getPageList(Map<String, String> map) {
        QueryWrapper wrapper = new QueryWrapper();
        wrapper.eq("`mark`", 1);
        Integer pageNo = 1;
        if (map != null) {
            //关键词筛选
            String keywords = "keywords";
            if (map.containsKey(keywords)) {
                if (FunctionUtils.isNumeric(map.get(keywords))) {
                    wrapper.eq("`id`", Integer.valueOf(map.get(keywords)));
                } else if (!FunctionUtils.isEmpty(keywords, map)) {
                    wrapper.like("`name`", map.get(keywords));
                    wrapper.or();
                    wrapper.like("`nid`", map.get(keywords));
                }
            }
            //添加人筛选
            String createUser = "createUser";
            if (!FunctionUtils.isEmpty(createUser, map)) {
                wrapper.eq("`create_user`", Integer.valueOf(map.get(createUser)));
            }
            //添加时间筛选
            String startTime = "startTime";
            String endTime = "endTime";
            if (map.containsKey(startTime) && map.containsKey(endTime) && FunctionUtils.isNumeric(map.get(startTime)) && FunctionUtils.isNumeric(map.get(endTime))) {
                wrapper.between("`create_time`", Integer.valueOf(map.get(startTime)), Integer.valueOf(map.get(endTime)));
            }
            //页数
            pageNo = map.containsKey("page") && Integer.valueOf(map.get("page")) > 0 ? Integer.valueOf(map.get("page")) : 1;
            //每页数量
            String pgSize = "pageSize";
            if (map.containsKey(pgSize) && Integer.valueOf(map.get(pgSize)) > 0) {
                pageSize = Integer.valueOf(map.get(pgSize));
            }
        }
        IPage<SysDictType> page = new Page<>(pageNo, pageSize);
        IPage<Map<String, Object>> data = dictTypeMapper.selectMapsPage(page, wrapper);
        if (!StringUtils.isEmpty(data.getRecords())) {
            for (Map<String, Object> mp : data.getRecords()) {
                Integer createUser = new Long(mp.get("create_user").toString()).intValue();
                mp.put("createUserName", adminService.getRealNameById(createUser));
                mp.put("formatCreateTime", mp.get("create_time").toString());
            }
        }
        return response.success("操作成功", data);
    }

    /**
     * 根据id获取数据
     *
     * @param id
     * @return
     */
    @Override
    public SysDictType getDictTypeById(Integer id) {
        SysDictType dictType = dictTypeMapper.selectById(id);
        return dictType;
    }

    /**
     * 添加、编辑数据
     *
     * @param map
     * @return
     */
    @Override
    public Response editData(SysDictType map) {
        //必填字段及格式校验
        Set<ConstraintViolation<SysDictType>> violations = validator.validate(map);
        for (ConstraintViolation<SysDictType> violation : violations) {
            if (!"".equals(violation.getMessage())) {
                return response.failure(violation.getMessage());
            }
        }
        if (map.getId() != null && map.getId() > 0) {
            map.setUpdateTime(DateUtil.now());
            map.setUpdateUser(ShiroUtils.getAdminId());
            updateById(map);
        } else {
            map.setCreateTime(DateUtil.now());
            map.setCreateUser(ShiroUtils.getAdminId());
            save(map);
        }
        return response.success("操作成功");
    }
}
