package com.taauav.front.controller;

import com.taauav.admin.service.ILsAdminService;
import com.taauav.admin.service.ITauvInspectFileService;
import com.taauav.common.bean.Response;
import com.taauav.front.dto.LsInspectFileDTO;
import com.taauav.front.utils.LoginUtils;
import com.taauav.front.vo.LSAdminVo;
import com.taauav.front.vo.LSVillageVo;
import com.taauav.front.vo.SysCityVo;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigInteger;
import java.util.List;
import java.util.Map;


/**
 * 前台用户
 *
 * @author daixiantong
 * @date 2020-04-14
 */
@RestController
@RequestMapping("/front/LsAdmin")
public class LSAdminController extends FrontBaseController  {
    @Autowired
    private ILsAdminService lsAdminService;
    @Autowired
    private Response response;
    @Autowired
    private ITauvInspectFileService inspectFileService;

    /**
     * 获取地图权限内区、镇/街道级数据
     * @param map
     * @return
     */
    @GetMapping("/info")
    public Response info(@RequestParam Map<String, String> map) {
        Integer userId = LoginUtils.getAdminId();
        LSAdminVo info = lsAdminService.getAdminInfo(userId);

        //数据权限处理
        List<SysCityVo> cityList = lsAdminService.getAdminAreaList(info, map);
        if (cityList != null) {
            info.setCityList(cityList);
        }

        return response.success(info);
    }

    /**
     * 根据镇/街道id获取权限内下属村数据
     * @param townId
     * @return
     */
    @GetMapping("/village")
    public Response getVillageData(@RequestParam("townId") BigInteger townId, @RequestParam Map<String, String> map) {
        Integer userId = LoginUtils.getAdminId();
        LSVillageVo village = lsAdminService.getVillageList(userId, townId, map);
        return response.success(village);
    }

    /**
     * 获取区划内问题坐标点
     * @param inspectFileDTO
     * @return
     */
    @GetMapping("/question")
    @ApiOperation(value = "获取区划内对应类型问题坐标点", notes = "传入cityId、category、巡检起止时间")
    public Response getQuestionPointList(LsInspectFileDTO inspectFileDTO) {
        return lsAdminService.getQuestionList(inspectFileDTO);
    }

    /**
     * 获取问题详情
     * @param inspectFileId
     * @return
     */
    @GetMapping("/detail")
    public Response getQuestionDetail(@RequestParam("inspectFileId") Integer inspectFileId) {
        return inspectFileService.getDetailById(inspectFileId);
    }
}
